@@ -1,5 +1,5 @@
 """
-filter1d - Time domain filtering of 1-D data tables
+filter1d - Time domain filtering of 1-D data tables.
 """
 
 from typing import Literal
@@ -57,25 +57,25 @@ def filter1d(
 
         Available convolution filter types are:
 
-        - (**b**) Boxcar: All weights are equal.
-        - (**c**) Cosine Arch: Weights follow a cosine arch curve.
-        - (**g**) Gaussian: Weights are given by the Gaussian function.
-        - (**f**) Custom: Instead of *width* give name of a one-column file
+        - **b**: boxcar. All weights are equal.
+        - **c**: cosine arch. Weights follow a cosine arch curve.
+        - **g**: Gaussian. Weights are given by the Gaussian function.
+        - **f**: custom. Instead of *width* give name of a one-column file
           with your own weight coefficients.
 
         Non-convolution filter types are:
 
-        - (**m**) Median: Returns median value.
-        - (**p**) Maximum likelihood probability (a mode estimator): Return
+        - **m**: median. Returns median value.
+        - **p**: maximum likelihood probability (a mode estimator). Return
           modal value. If more than one mode is found we return their average
           value. Append **+l** or **+u** if you rather want
           to return the lowermost or uppermost of the modal values.
-        - (**l**) Lower: Return the minimum of all values.
-        - (**L**) Lower: Return minimum of all positive values only.
-        - (**u**) Upper: Return maximum of all values.
-        - (**U**) Upper: Return maximum of all negative values only.
+        - **l**: lower (absolute). Return the minimum of all values.
+        - **L**: lower. Return minimum of all positive values only.
+        - **u**: upper (absolute). Return maximum of all values.
+        - **U**: upper. Return maximum of all negative values only.
 
-        Upper case type **B**, **C**, **G**, **M**, **P**, **F** will use
+        Uppercase type **B**, **C**, **G**, **M**, **P**, **F** will use
         robust filter versions: i.e., replace outliers (2.5 L1 scale off
         median, using 1.4826 \* median absolute deviation [MAD]) with median
         during filtering.
@@ -105,12 +105,14 @@ def filter1d(
     ret
         Return type depends on ``outfile`` and ``output_type``:
 
-        - None if ``outfile`` is set (output will be stored in file set by ``outfile``)
+        - ``None`` if ``outfile`` is set (output will be stored in the file set by
+          ``outfile``)
         - :class:`pandas.DataFrame` or :class:`numpy.ndarray` if ``outfile`` is not set
           (depends on ``output_type``)
     """
     if kwargs.get("F") is None:
-        raise GMTInvalidInput("Pass a required argument to 'filter_type'.")
+        msg = "Pass a required argument to 'filter_type'."
+        raise GMTInvalidInput(msg)
 
     output_type = validate_output_table_type(output_type, outfile=outfile)
 
