@@ -1,5 +1,5 @@
 """
-grdtrack - Sample grids at specified (x,y) locations.
+grdtrack - Sample one or more grids at specified locations.
 """
 
 from typing import Literal
@@ -56,7 +56,7 @@ def grdtrack(
     **kwargs,
 ) -> pd.DataFrame | np.ndarray | None:
     r"""
-    Sample grids at specified (x,y) locations.
+    Sample one or more grids at specified locations.
 
     Reads one or more grid files and a table (from file or an array input; but
     see ``profile`` for exception) with (x,y) [or (lon,lat)] positions in the
@@ -191,7 +191,7 @@ def grdtrack(
     {region}
     no_skip : bool
         Do *not* skip points that fall outside the domain of the grid(s)
-        [Default only output points within grid domain].
+        [Default only output points within the grid domain].
     stack : str or list
         *method*/*modifiers*.
         In conjunction with ``crossprofile``, compute a single stacked profile
@@ -290,13 +290,16 @@ def grdtrack(
     ... )
     """
     if points is not None and kwargs.get("E") is not None:
-        raise GMTInvalidInput("Can't set both 'points' and 'profile'.")
+        msg = "Can't set both 'points' and 'profile'."
+        raise GMTInvalidInput(msg)
 
     if points is None and kwargs.get("E") is None:
-        raise GMTInvalidInput("Must give 'points' or set 'profile'.")
+        msg = "Must give 'points' or set 'profile'."
+        raise GMTInvalidInput(msg)
 
     if hasattr(points, "columns") and newcolname is None:
-        raise GMTInvalidInput("Please pass in a str to 'newcolname'")
+        msg = "Please pass in a str to 'newcolname'."
+        raise GMTInvalidInput(msg)
 
     output_type = validate_output_table_type(output_type, outfile=outfile)
 
