@@ -1,7 +1,8 @@
 """
-sph2grd - Compute grid from spherical harmonic coefficients
+sph2grd - Compute grid from spherical harmonic coefficients.
 """
 
+import xarray as xr
 from pygmt.clib import Session
 from pygmt.helpers import build_arg_list, fmt_docstring, kwargs_to_strings, use_alias
 
@@ -20,9 +21,9 @@ __doctest_skip__ = ["sph2grd"]
     x="cores",
 )
 @kwargs_to_strings(I="sequence", R="sequence", i="sequence_comma")
-def sph2grd(data, outgrid: str | None = None, **kwargs):
+def sph2grd(data, outgrid: str | None = None, **kwargs) -> xr.DataArray | None:
     r"""
-    Create spherical grid files in tension of data.
+    Compute grid from spherical harmonic coefficients.
 
     Reads a spherical harmonics coefficient table with records of L, M,
     C[L,M], S[L,M] and evaluates the spherical harmonic model on the
@@ -50,7 +51,7 @@ def sph2grd(data, outgrid: str | None = None, **kwargs):
 
     Returns
     -------
-    ret: xarray.DataArray or None
+    ret
         Return type depends on whether the ``outgrid`` parameter is set:
 
         - :class:`xarray.DataArray` if ``outgrid`` is not set
