@@ -1,12 +1,13 @@
 """
-triangulate - Delaunay triangulation or Voronoi partitioning and gridding of
-Cartesian data.
+triangulate - Delaunay triangulation or Voronoi partitioning and gridding of Cartesian
+data.
 """
 
 from typing import Literal
 
 import numpy as np
 import pandas as pd
+import xarray as xr
 from pygmt.clib import Session
 from pygmt.helpers import (
     build_arg_list,
@@ -65,7 +66,7 @@ class triangulate:  # noqa: N801
     @kwargs_to_strings(I="sequence", R="sequence", i="sequence_comma")
     def regular_grid(
         data=None, x=None, y=None, z=None, outgrid: str | None = None, **kwargs
-    ):
+    ) -> xr.DataArray | None:
         """
         Delaunay triangle based gridding of Cartesian data.
 
@@ -93,7 +94,7 @@ class triangulate:  # noqa: N801
 
         Parameters
         ----------
-        x/y/z : np.ndarray
+        x/y/z : :class:`numpy.ndarray`
             Arrays of x and y coordinates and values z of the data points.
         data : str, {table-like}
             Pass in (x, y[, z]) or (longitude, latitude[, elevation]) values by
@@ -121,12 +122,11 @@ class triangulate:  # noqa: N801
 
         Returns
         -------
-        ret: xarray.DataArray or None
+        ret
             Return type depends on whether the ``outgrid`` parameter is set:
 
-            - xarray.DataArray if ``outgrid`` is None (default)
-            - None if ``outgrid`` is a str (grid output is stored in
-              ``outgrid``)
+            - :class:`xarray.DataArray` if ``outgrid`` is ``None`` [Default]
+            - ``None`` if ``outgrid`` is a str (grid output is stored in ``outgrid``)
 
         Note
         ----
@@ -196,7 +196,7 @@ class triangulate:  # noqa: N801
 
         Parameters
         ----------
-        x/y/z : np.ndarray
+        x/y/z : :class:`numpy.ndarray`
             Arrays of x and y coordinates and values z of the data points.
         data : str, {table-like}
             Pass in (x, y, z) or (longitude, latitude, elevation) values by
@@ -221,7 +221,7 @@ class triangulate:  # noqa: N801
         ret
             Return type depends on ``outfile`` and ``output_type``:
 
-            - ``None`` if ``outfile`` is set (output will be stored in file set by
+            - ``None`` if ``outfile`` is set (output will be stored in the file set by
               ``outfile``)
             - :class:`pandas.DataFrame` or :class:`numpy.ndarray` if ``outfile`` is not
               set (depends on ``output_type``)
@@ -233,7 +233,7 @@ class triangulate:  # noqa: N801
         ``triangulate`` is a Cartesian or small-geographic area operator and is
         unaware of periodic or polar boundary conditions.
         """
-        output_type = validate_output_table_type(output_type, outfile)
+        output_type = validate_output_table_type(output_type, outfile=outfile)
 
         with Session() as lib:
             with (
